Peacasso [Beta] | Home

Peacasso is a UI tool to help you generate art (and experiment) with AI models (diffusion) models. Feedback welcome! .
Write a prompt (and upload an image) and get a generated response.
width: 512, height: 512, number of images: 6 ...
Generation Settings
Generation Mode
prompt image
generated image is based on the text prompt.
Need inspiration? Try out one of the sample prompts below
portrait of leprechaun, intricate, elegant, highly detailed, digital painting, artstation, concept art, smooth, sharp focus, illustration, art by artgerm and greg rutkowski and alphonse mucha, 8 k
portrait photo of a asia old warrior chief, tribal panther make up, blue on red, side profile, looking away, serious eyes, 50mm portrait photography, hard rim lighting photography--beta
formal portrait of clint eastwood as wyatt earp, digital art by eugene de blaas, ross tran, and nasreddine dinet, vibrant color scheme, intricately detailed, in the style of romanticism, cinematic, artstation, greg rutkowski
cinematic bust portrait of psychedelic robot from left, head and chest only, exotic alien features, robotic enhancements, desaturated, tim hildebrandt, wayne barlowe, bruce pennington, donato giancola, larry elmore, oil on canvas, masterpiece, trending on artstation, featured on pixiv, cinematic composition, dramatic pose, beautiful lighting, sharp, details, hyper - detailed, hd, hdr, 4 k, 8 k
victorian ampitheater of sand, pillars with statues on top, lamps on ground, by peter mohrbacher dan mumford craig mullins nekro, cgsociety, pixiv, volumetric light, 3 d render
Learn more about peacasso on Github.